==> kaffeine-trinity-3.5.13.2.tar.xz: kaffeine-trinity-3.5.13.2/kaffeine/src/input/dvb/plugins/stream/kaffeinedvbplugin.h <==
/*
 * kaffeinedvbplugin.h
 *
 * Copyright (C) 2006 Christophe Thommeret <hftom@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef KAFFEINEDVBPLUGIN_H
#define KAFFEINEDVBPLUGIN_H

#include <tqpopupmenu.h>
#include <tqstring.h>

#include <kparts/part.h>
#include <kconfig.h>

/*
 * Base-Class for Kaffeine DVB plugins.
 */

class KDE_EXPORT KaffeineDvbPlugin : public KParts::Part
{
	Q_OBJECT
  TQ_OBJECT
public:
	KaffeineDvbPlugin(TQObject* parent, const char* name);
	virtual ~KaffeineDvbPlugin();
	virtual TQString pluginName() { return TQString(); }

	// returns a "handle".
	virtual void* init( int /*sid*/ , int /*anum*/, int /*tnum*/, int /*fta*/ ) { return NULL; }

	virtual void process( void* /*handle*/, unsigned char* /*buf*/, int /*len*/ ) {};
	virtual void close( void* /*handle*/ ) {};

public slots:
	virtual void configDialog() {};
};

#endif /* KAFFEINEDVBPLUGIN_H */

==> kaffeine-trinity-14.0.8.tar.xz: kaffeine-trinity-14.0.8/kaffeine/src/input/dvb/plugins/stream/kaffeinedvbplugin.h <==
/*
 * kaffeinedvbplugin.h
 *
 * Copyright (C) 2006 Christophe Thommeret <hftom@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef KAFFEINEDVBPLUGIN_H
#define KAFFEINEDVBPLUGIN_H

#include <tqpopupmenu.h>
#include <tqstring.h>

#include <tdeparts/part.h>
#include <tdeconfig.h>

/*
 * Base-Class for Kaffeine DVB plugins.
 */

class KDE_EXPORT KaffeineDvbPlugin : public KParts::Part
{
	Q_OBJECT
  
public:
	KaffeineDvbPlugin(TQObject* parent, const char* name);
	virtual ~KaffeineDvbPlugin();
	virtual TQString pluginName() { return TQString(); }

	// returns a "handle".
	virtual void* init( int /*sid*/ , int /*anum*/, int /*tnum*/, int /*fta*/ ) { return NULL; }

	virtual void process( void* /*handle*/, unsigned char* /*buf*/, int /*len*/ ) {};
	virtual void close( void* /*handle*/ ) {};

public slots:
	virtual void configDialog() {};
};

#endif /* KAFFEINEDVBPLUGIN_H */
